![](https://raw.githubusercontent.com/gibbons-eddie/Stinder/main/stinder/resources/images/IMG_4845.JPG)

<h3>Do you hate having to group up with students you don't know? Have you ever been stuck doing all the work?</h3>
<h3>Us too.</h3>

Stinder aims to solve those problems for those who would like to pair up with those with similar work ethic and motivations. Fill out your student information for your profile and browse through your class population for those with similar qualities to work as effectively as possible in a group setting! Filter students by major, coursework, schedule and more* to find your perfect match!

***Stinder. Never have a bad (study) date again.***

To download Stinder, run: 

    pip install stinder
    Stinder

[*Trello*](https://trello.com/b/WMZnG8PD/stinder)

[*GitHub*](https://github.com/gibbons-eddie/Stinder)

[*PyPi*](https://pypi.org/project/stinder/0.0.1/)
